/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse;

import org.eclipse.core.runtime.Plugin;
import org.fortiss.tooling.ext.reuse.model.ReuseLibrary;
import org.fortiss.tooling.kernel.service.IConstraintCheckerService;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 *
 * @author bergemann
 */
public class ToolingReuseActivator extends Plugin {

	/** The plug-in ID. */
	public static final String PLUGIN_ID = ToolingReuseActivator.class.getPackage().getName(); // $NON-NLS-1$

	/** The shared instance. */
	private static ToolingReuseActivator plugin;

	/** {@inheritDoc} */
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;

		// Objects within a ReuseLibrary do not need to comply with the constraint checks with which
		// they should comply when they are outside of it (in a normal project). This is why the
		// ReuseLibrary needs to be registered as an exclusion for all the usual constraint checks.
		IConstraintCheckerService ccs = IConstraintCheckerService.getInstance();
		ccs.registerTypeAsExcludedParentForConstraintChecks(ReuseLibrary.class);
	}

	/** {@inheritDoc} */
	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 *
	 * @return The shared instance of ToolingReuseActivator
	 */
	public static ToolingReuseActivator getDefault() {
		return plugin;
	}
}
