/*--------------------------------------------------------------------------+
|                                                                          |
| Copyright 2022 fortiss GmbH             						           |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.ui.editor;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.eclipse.jface.viewers.TextCellEditor;
import org.eclipse.swt.widgets.Composite;
import org.fortiss.tooling.kernel.service.ICommandStackService;
import org.fortiss.variability.model.IAlternative;

/**
 * Name editing support for alternatives of alternative variation points.
 * 
 * @author bayha
 */
class AlternativesNamesEditingSupport extends EditingSupport {

	/** Constructor. */
	public AlternativesNamesEditingSupport(ColumnViewer viewer) {
		super(viewer);
	}

	/** {@inheritDoc} */
	@Override
	protected CellEditor getCellEditor(Object element) {
		return new TextCellEditor((Composite)getViewer().getControl());
	}

	/** {@inheritDoc} */
	@Override
	protected boolean canEdit(Object element) {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	protected Object getValue(Object element) {
		if(element instanceof IAlternative) {
			return ((IAlternative)element).getName();
		}
		return "";
	}

	/** {@inheritDoc} */
	@Override
	protected void setValue(Object element, Object value) {
		if(element instanceof IAlternative && value instanceof String) {
			IAlternative alternative = (IAlternative)element;
			String name = (String)value;
			ICommandStackService.getInstance().runAsCommand(alternative,
					() -> alternative.setName(name));
		}
	}
}
