/*-------------------------------------------------------------------------+
| Copyright 2022 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.variability.analysis;

import static java.util.Collections.emptySet;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * {@link Map} implementation which maps a key to a {@link Set} of values.
 * 
 * @author bayha
 */
public class BucketSetMap<K, V> extends HashMap<K, Set<V>> {
	/** ISerializable */
	private static final long serialVersionUID = 312480465506162554L;

	/**
	 * Adds a given value to the set for the given key.
	 * 
	 * @param key
	 *            The key for which an additional value shall be added.
	 * @param value
	 *            The additional value that shall be added.
	 * 
	 * @return The new set of values for the given key.
	 */
	public Set<V> add(K key, V value) {
		Set<V> set = super.get(key);

		if(set == null) {
			set = new HashSet<V>();
			this.put(key, set);
		}

		set.add(value);

		return set;
	}

	/** {@inheritDoc} */
	@Override
	public Set<V> get(Object key) {
		Set<V> ret = super.get(key);

		if(ret == null) {
			return emptySet();
		}

		return ret;
	}
}
